==> impresscms-1.2.3.tbz: www/impresscms/htdocs/modules/system/language/english/admin/rating.php <==
<?php

/**
* $Id: rating.php 159 2007-12-17 16:44:05Z malanciault $
* Module: SmartContent
* Author: The SmartFactory <www.smartfactory.ca>
* Licence: GNU
*/
if (!defined("XOOPS_ROOT_PATH")) {
 	die("XOOPS root path not defined");
}

define('_CO_ICMS_RATING_RATE_IT', 'Rate it !');
define('_CO_ICMS_RATING_DUPLICATE_ENTRY', 'Sorry ! You have already rated this ! You cannot rate something twice.');
define('_CO_ICMS_RATING_ERROR', 'An error occured, your rating could not be stored.');
define('_CO_ICMS_RATING_SUCCESS', 'Your rating has been stored. Thank for your contribution !');
define('_CO_ICMS_RATING_RATE_THIS', 'Was this usefull ? (1 being <i>Not usefull</i> and 5 being <i>Very usefull</i>)');
define('_CO_ICMS_RATING_ALREADY_RATED', 'Your rate: ');
define('_CO_ICMS_RATING_VOTERS_TOTAL', 'Voters total: ');
define('_CO_ICMS_RATING_AVERAGE', 'Average: ');
define('_CO_ICMS_RATINGS', 'Rating');
define('_CO_ICMS_RATINGS_DSC', 'Here is a list of the ratings added in the system.');
define('_CO_ICMS_RATING', 'Rating');
define('_CO_ICMS_RATINGS_CREATE', 'Add a rating');
define('_CO_ICMS_RATING_CREATE', 'Add a rating');
define('_CO_ICMS_RATINGS_CREATE_INFO', 'Simply fill this form in order to add a rating.');
define('_CO_ICMS_RATING_DELETE_CONFIRM', 'Do you really want to delete this rating from the system ?');
define('_CO_ICMS_RATINGS_EDIT', 'Edit a rating');
define('_CO_ICMS_RATINGS_EDIT_INFO', 'Use this form to edit the information of this rating.');
define('_CO_ICMS_RATINGS_INFO', 'Rating information');
define('_CO_ICMS_RATING_NOT_FOUND', 'The selected rating was not found.');
define('_CO_ICMS_RATINGS_CREATED', 'The rating was successfully created.');
define('_CO_ICMS_RATINGS_MODIFIED', 'The rating was successfully modified.');
define('_CO_ICMS_RATING_EXPLAIN_TITLE', 'What are Ratings ?');
define('_CO_ICMS_RATING_EXPLAIN', 'Ratings is a new feature in ImpressCMS. With using this tool, you can add a new rating method to your modules, and control the results through this section! Complete documentation of this feature can be found here: <a rel="external" href="http://wiki.impresscms.org/index.php?title=Rating_feature">Rating Features</a>.');
?>

==> impresscms-1.3.1.tbz: www/impresscms/htdocs/modules/system/language/english/admin/rating.php <==
<?php
/**
* rating definations
*
* @copyright      http://www.impresscms.org/ The ImpressCMS Project
* @license         LICENSE.txt
* @package	ratings
* @author		marcan <macrcan@impresscms.org>
* @version		$Id$
*/

if (!defined('ICMS_ROOT_PATH')) die("ImpressCMS root path not defined");

define('_CO_ICMS_RATING_RATE_IT', 'Rate it !');
define('_CO_ICMS_RATING_DUPLICATE_ENTRY', 'Sorry ! You have already rated this ! You cannot rate something twice.');
define('_CO_ICMS_RATING_ERROR', 'An error occured, your rating could not be stored.');
define('_CO_ICMS_RATING_SUCCESS', 'Your rating has been stored. Thank for your contribution !');
define('_CO_ICMS_RATING_RATE_THIS', 'Was this usefull ? (1 being <i>Not usefull</i> and 5 being <i>Very usefull</i>)');
define('_CO_ICMS_RATING_ALREADY_RATED', 'Your rate: ');
define('_CO_ICMS_RATING_VOTERS_TOTAL', 'Voters total: ');
define('_CO_ICMS_RATING_AVERAGE', 'Average: ');
define('_CO_ICMS_RATINGS', 'Rating');
define('_CO_ICMS_RATINGS_DSC', 'Here is a list of the ratings added in the system.');
define('_CO_ICMS_RATING', 'Rating');
define('_CO_ICMS_RATINGS_CREATE', 'Add a rating');
define('_CO_ICMS_RATING_CREATE', 'Add a rating');
define('_CO_ICMS_RATINGS_CREATE_INFO', 'Simply fill this form in order to add a rating.');
define('_CO_ICMS_RATING_DELETE_CONFIRM', 'Do you really want to delete this rating from the system ?');
define('_CO_ICMS_RATINGS_EDIT', 'Edit a rating');
define('_CO_ICMS_RATINGS_EDIT_INFO', 'Use this form to edit the information of this rating.');
define('_CO_ICMS_RATINGS_INFO', 'Rating information');
define('_CO_ICMS_RATING_NOT_FOUND', 'The selected rating was not found.');
define('_CO_ICMS_RATINGS_CREATED', 'The rating was successfully created.');
define('_CO_ICMS_RATINGS_MODIFIED', 'The rating was successfully modified.');
define('_CO_ICMS_RATING_EXPLAIN_TITLE', 'What are Ratings ?');
define('_CO_ICMS_RATING_EXPLAIN', 'Ratings is a new feature in ImpressCMS. With using this tool, you can add a new rating method to your modules, and control the results through this section! Complete documentation of this feature can be found here: <a rel="external" href="http://wiki.impresscms.org/index.php?title=Rating_feature">Rating Features</a>.');
